import { jsx as _jsx } from "react/jsx-runtime";
// eslint-disable-next-line import/no-unresolved
import { useSyncExternalStore } from "use-sync-external-store/shim";
import { createContext, useContext, useRef } from "react";
const ReduxContext = createContext(null);
/**
 * The redux store provider
 * @param props store and children
 */
export const Provider = ({ store, children }) => (_jsx(ReduxContext.Provider, { value: store, children: children }));
/**
 * A hook to access the redux store
 * @throws When a `Provider` is missing.
 */
export function useStore() {
    const store = useContext(ReduxContext);
    if (!store) {
        throw new Error("Could not find react redux context. Make sure you've added a Provider.");
    }
    return store;
}
/** Compare by reference */
export function compareRef(a, b) {
    return a === b;
}
/**
 * A hook to use a selector function to access redux state.
 * @param selector  The selector function to retrieve a value from the redux store. It receives the current redux state.
 * @param compare   The comparison function to use in order to only trigger a fresh render when something changed. Default compare by reference.
 * @throws When a `Provider` is missing.
 */
export function useSelector(selector, compare = compareRef) {
    const store = useStore();
    const cache = useRef(null);
    return useSyncExternalStore(store.subscribe, () => {
        const value = selector(store.getState());
        if (!cache.current || !compare(cache.current.value, value)) {
            cache.current = { value };
        }
        return cache.current.value;
    });
}
/**
 * A hook to get the redux stores dispatch function.
 * @throws When a `Provider` is missing.
 */
export function useDispatch() {
    return useStore().dispatch;
}
